@@ -15,6 +15,8 @@ def spec(model,
         pol=False, 
         nside=64, 
         sky_fractions=(25,85), 
+        xlim=(0.25, 4000),
+        long=True,
         darkmode=False, 
         ame_polfrac=0.02,
         haslam = True,
@@ -25,6 +27,7 @@ def spec(model,
         wmap = True,
         planck = True,
         dirbe = True,
+        litebird = False,
         include_co=True,
         add_error = True):
     # TODO, they need to be smoothed to common res!
@@ -63,9 +66,11 @@ def spec(model,
  
     #plt.rcParams.update(plt.rcParamsDefault)
 
-    long = True
     sig = 1 if pol else 0
-    xmin, xmax = (0.25, 4000) if long else (9, 1500)
+    if xlim==(0.25, 4000):
+        if not long:
+            xlim=(9, 1500)
+    xmin, xmax = xlim
     ymin, ymax = (0.05, 7e2) if not pol else (1.001e-3, 2e2)
     ymin2, ymax2 = (ymax+100, 1e7)
     # textsize
@@ -115,17 +120,26 @@ def spec(model,
     i = 0
     
     for comp in foregrounds.keys():
-        if comp in seds.keys():
-            foregrounds[comp]["spectrum"] = seds[comp]
+        if comp.startswith("co") and include_co: # get closest thing to ref freq
+            foregrounds[comp]["params"][2], line_idx = find_nearest(nu, foregrounds[comp]["params"][2])
+            foregrounds[comp]["spectrum"] = np.zeros((2,len(sky_fractions),N))
+            foregrounds[comp]["spectrum"][sig][0][line_idx] = foregrounds[comp]["params"][0]
+            foregrounds[comp]["spectrum"][sig][1][line_idx] = foregrounds[comp]["params"][1]
+
         if comp.startswith("bb"):
             a=0.67*1e-1 if comp.endswith("2") else 0.67*1e-2
             sed = np.zeros((2,len(sky_fractions),N))
             sed[1]=a*model.components["cmb"].get_freq_scaling(nu*u.GHz,)
             foregrounds[comp]["spectrum"] = sed
+
+        if comp in seds.keys():
+            foregrounds[comp]["spectrum"] = seds[comp]
+        else:
+            continue
+
         if pol and comp=="ame":
             foregrounds[comp]["spectrum"][1] = ame_polfrac*foregrounds[comp]["spectrum"][0]
 
-    
         if foregrounds[comp]["sum"] and foregrounds[comp]["spectrum"] is not None:
             if i==0:
                 foregrounds["sumfg"]["spectrum"] = foregrounds[comp]["spectrum"].copy()
@@ -133,17 +147,12 @@ def spec(model,
                 foregrounds["sumfg"]["spectrum"] += foregrounds[comp]["spectrum"]
             i+=1
 
-        if add_error and not comp.startswith("co"):
+        if add_error and not comp.startswith("co") and not comp.startswith("bb"):
             thresh=0.1                    
             alpha=0.5
             foregrounds[comp]["spectrum"][sig][0] = foregrounds[comp]["spectrum"][sig][0]*(1-np.exp(-(abs(foregrounds[comp]["spectrum"][sig][0]/thresh)**alpha)))
             foregrounds[comp]["spectrum"][sig][1] = foregrounds[comp]["spectrum"][sig][1]/(1-np.exp(-(abs(foregrounds[comp]["spectrum"][sig][1]/thresh)**alpha)))
 
-        if comp.startswith("co") and include_co: # get closest thing to ref freq
-            foregrounds[comp]["params"][2], line_idx = find_nearest(nu, foregrounds[comp]["params"][2])
-            foregrounds[comp]["spectrum"] = np.zeros((2,len(sky_fractions),N))
-            foregrounds[comp]["spectrum"][sig][0][line_idx] = foregrounds[comp]["params"][0]
-            foregrounds[comp]["spectrum"][sig][1][line_idx] = foregrounds[comp]["params"][1]
     # ---- Plotting foregrounds and labels ----
     j=0
     for comp, params in foregrounds.items(): # Plot all fgs except sumf
@@ -240,6 +249,21 @@ def spec(model,
                              "Q":       {"pol": True, "show": wmap, "position": [39.,  ymin*yscaletextup], "range": [38,45], "color": teal,}, 
                              "V":       {"pol": True, "show": wmap, "position": [58.,  ymin*yscaletextup], "range": [54,68], "color": teal,}, 
                              "W":       {"pol": True, "show": wmap, "position": [90.,  ymin*yscaletextup], "range": [84,106], "color": teal,}}, 
+                 "LiteBIRD":  {"40":          {"pol": True, "show": litebird, "position": [40,  ymax2*yscaletext], "range": [34,46],"color": red,}, 
+                            "50":          {"pol": True, "show": litebird, "position": [50,  ymax2*yscaletext], "range": [43,57]    ,"color": red,},
+                            "60":          {"pol": True, "show": litebird, "position": [60,  ymax2*yscaletext], "range": [53,67]    ,"color": red,},
+                            "68":          {"pol": True, "show": litebird, "position": [68,  ymax2*yscaletext], "range": [60,76]   ,"color": red,},
+                            "78":          {"pol": True, "show": litebird, "position": [78, ymax2*yscaletext], "range": [69,87]  ,"color": red,},
+                            "89":          {"pol": True, "show": litebird, "position": [89, ymax2*yscaletext], "range": [79,99]  ,"color": red,},
+                            "100":         {"pol": True, "show": litebird, "position": [100, ymax2*yscaletext], "range": [89,111]  ,"color": red,},
+                            "119":         {"pol": True, "show": litebird, "position": [119, ymax2*yscaletext], "range": [101,137]  ,"color": red,},
+                            "140":         {"pol": True, "show": litebird, "position": [140, ymax2*yscaletext], "range": [119,161] ,"color": red,},
+                            "166":         {"pol": True, "show": litebird, "position": [166, ymax2*yscaletext], "range": [141,191] ,"color": red,},
+                            "195":         {"pol": True, "show": litebird, "position": [195, ymax2*yscaletext], "range": [165,225] ,"color": red,},
+                            "235":         {"pol": True, "show": litebird, "position": [235, ymax2*yscaletext], "range": [200,270] ,"color": red,},
+                            "280":         {"pol": True, "show": litebird, "position": [280, ymax2*yscaletext], "range": [238,322] ,"color": red,},
+                            "337":         {"pol": True, "show": litebird, "position": [337, ymax2*yscaletext], "range": [287,387] ,"color": red,},
+                            "402\nLiteBIRD":         {"pol": True, "show": litebird, "position": [402, ymax2*yscaletext], "range": [356,458] ,"color": red,}}, 
     }
     # Set databands from dictonary
     for experiment, bands in databands.items():
